"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .toolauthtype import ToolAuthType
from datetime import datetime
from pydantic import model_serializer
from syllable_sdk.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from typing import List
from typing_extensions import NotRequired, TypedDict


class ServiceResponseTypedDict(TypedDict):
    r"""Response model for service operations. A service is a collection of tools."""

    id: int
    r"""The internal ID of the service"""
    name: str
    r"""The name of the service"""
    description: str
    r"""The description of the service"""
    last_updated: datetime
    r"""The timestamp of the most recent update to the service"""
    last_updated_by: str
    r"""The email of the user who last updated the service"""
    tools: List[str]
    r"""Names of tools that belong to the service"""
    auth_type: NotRequired[Nullable[ToolAuthType]]
    r"""The type of authentication to use for the service's tools"""
    auth_value_keys: NotRequired[Nullable[List[str]]]
    r"""Auth value keys (values omitted for security)"""
    last_updated_comments: NotRequired[Nullable[str]]
    r"""Free text providing comment about what was updated"""


class ServiceResponse(BaseModel):
    r"""Response model for service operations. A service is a collection of tools."""

    id: int
    r"""The internal ID of the service"""

    name: str
    r"""The name of the service"""

    description: str
    r"""The description of the service"""

    last_updated: datetime
    r"""The timestamp of the most recent update to the service"""

    last_updated_by: str
    r"""The email of the user who last updated the service"""

    tools: List[str]
    r"""Names of tools that belong to the service"""

    auth_type: OptionalNullable[ToolAuthType] = UNSET
    r"""The type of authentication to use for the service's tools"""

    auth_value_keys: OptionalNullable[List[str]] = UNSET
    r"""Auth value keys (values omitted for security)"""

    last_updated_comments: OptionalNullable[str] = UNSET
    r"""Free text providing comment about what was updated"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["auth_type", "auth_value_keys", "last_updated_comments"]
        nullable_fields = ["auth_type", "auth_value_keys", "last_updated_comments"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from pydantic import model_serializer
from syllable_sdk.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from typing_extensions import NotRequired, TypedDict


class TelephonyConfigurationsTypedDict(TypedDict):
    pre_input_timeout: NotRequired[Nullable[float]]
    r"""Pre input silence threshold"""
    post_speech_input_timeout: NotRequired[Nullable[float]]
    r"""Post speech silence timeout to determine input as ended."""
    post_dtmf_input_timeout: NotRequired[Nullable[float]]
    r"""Post dtmf silence timeout to determine input as ended."""
    overall_input_timeout: NotRequired[Nullable[float]]
    r"""Total input timeout"""
    output_padding: NotRequired[Nullable[float]]
    r"""Number of seconds to start listening to user input before assistant speech ends"""


class TelephonyConfigurations(BaseModel):
    pre_input_timeout: OptionalNullable[float] = UNSET
    r"""Pre input silence threshold"""

    post_speech_input_timeout: OptionalNullable[float] = UNSET
    r"""Post speech silence timeout to determine input as ended."""

    post_dtmf_input_timeout: OptionalNullable[float] = UNSET
    r"""Post dtmf silence timeout to determine input as ended."""

    overall_input_timeout: OptionalNullable[float] = UNSET
    r"""Total input timeout"""

    output_padding: OptionalNullable[float] = UNSET
    r"""Number of seconds to start listening to user input before assistant speech ends"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "pre_input_timeout",
            "post_speech_input_timeout",
            "post_dtmf_input_timeout",
            "overall_input_timeout",
            "output_padding",
        ]
        nullable_fields = [
            "pre_input_timeout",
            "post_speech_input_timeout",
            "post_dtmf_input_timeout",
            "overall_input_timeout",
            "output_padding",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .basesdk import BaseSDK
from syllable_sdk import errors, models, utils
from syllable_sdk._hooks import HookContext
from syllable_sdk.types import BaseModel, OptionalNullable, UNSET
from syllable_sdk.utils import get_security_from_env
from syllable_sdk.utils.unmarshal_json_response import unmarshal_json_response
from typing import Any, List, Mapping, Optional, Union, cast


class CustomMessages(BaseSDK):
    r"""Operations related to custom message configuration.           A custom message is a pre-configured message delivered by an agent as a greeting at the           beginning of a conversation. Multiple agents can use the same custom mesasage. A custom           message has one or more rules defined, which allow for different messages to be           dynamically selected and delivered at runtime based on the current time and either           date or day of the week. For more information, see           [Console docs](https://docs.syllable.ai/Resources/Messages)."""

    def list(
        self,
        *,
        page: OptionalNullable[int] = UNSET,
        limit: Optional[int] = 25,
        search_fields: Optional[List[models.CustomMessageProperties]] = None,
        search_field_values: Optional[List[str]] = None,
        order_by: OptionalNullable[models.CustomMessageProperties] = UNSET,
        order_by_direction: OptionalNullable[models.OrderByDirection] = UNSET,
        fields: OptionalNullable[List[models.CustomMessageProperties]] = UNSET,
        start_datetime: OptionalNullable[str] = UNSET,
        end_datetime: OptionalNullable[str] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.ListResponseCustomMessageResponse:
        r"""Custom Messages List

        List the existing custom_messages

        :param page: The page number from which to start (0-based)
        :param limit: The maximum number of items to return
        :param search_fields: String names of fields to search. Correspond by index to search field values
        :param search_field_values: Values of fields to search. Correspond by index to search fields. Unless field name contains \"list\", an individual search field value cannot be a list
        :param order_by: The field whose value should be used to order the results
        :param order_by_direction: The direction in which to order the results
        :param fields: The fields to include in the response
        :param start_datetime: The start datetime for filtering results
        :param end_datetime: The end datetime for filtering results
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.CustomMessagesListRequest(
            page=page,
            limit=limit,
            search_fields=search_fields,
            search_field_values=search_field_values,
            order_by=order_by,
            order_by_direction=order_by_direction,
            fields=fields,
            start_datetime=start_datetime,
            end_datetime=end_datetime,
        )

        req = self._build_request(
            method="GET",
            path="/api/v1/custom_messages/",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="custom_messages_list",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["422", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(
                models.ListResponseCustomMessageResponse, http_res
            )
        if utils.match_response(http_res, "422", "application/json"):
            response_data = unmarshal_json_response(
                errors.HTTPValidationErrorData, http_res
            )
            raise errors.HTTPValidationError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)

    async def list_async(
        self,
        *,
        page: OptionalNullable[int] = UNSET,
        limit: Optional[int] = 25,
        search_fields: Optional[List[models.CustomMessageProperties]] = None,
        search_field_values: Optional[List[str]] = None,
        order_by: OptionalNullable[models.CustomMessageProperties] = UNSET,
        order_by_direction: OptionalNullable[models.OrderByDirection] = UNSET,
        fields: OptionalNullable[List[models.CustomMessageProperties]] = UNSET,
        start_datetime: OptionalNullable[str] = UNSET,
        end_datetime: OptionalNullable[str] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.ListResponseCustomMessageResponse:
        r"""Custom Messages List

        List the existing custom_messages

        :param page: The page number from which to start (0-based)
        :param limit: The maximum number of items to return
        :param search_fields: String names of fields to search. Correspond by index to search field values
        :param search_field_values: Values of fields to search. Correspond by index to search fields. Unless field name contains \"list\", an individual search field value cannot be a list
        :param order_by: The field whose value should be used to order the results
        :param order_by_direction: The direction in which to order the results
        :param fields: The fields to include in the response
        :param start_datetime: The start datetime for filtering results
        :param end_datetime: The end datetime for filtering results
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.CustomMessagesListRequest(
            page=page,
            limit=limit,
            search_fields=search_fields,
            search_field_values=search_field_values,
            order_by=order_by,
            order_by_direction=order_by_direction,
            fields=fields,
            start_datetime=start_datetime,
            end_datetime=end_datetime,
        )

        req = self._build_request_async(
            method="GET",
            path="/api/v1/custom_messages/",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="custom_messages_list",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["422", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(
                models.ListResponseCustomMessageResponse, http_res
            )
        if utils.match_response(http_res, "422", "application/json"):
            response_data = unmarshal_json_response(
                errors.HTTPValidationErrorData, http_res
            )
            raise errors.HTTPValidationError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)

    def create(
        self,
        *,
        request: Union[
            models.CustomMessageCreateRequest,
            models.CustomMessageCreateRequestTypedDict,
        ],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.CustomMessageResponse:
        r"""Create Custom Message

        Create a new custom message

        :param request: The request object to send.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        if not isinstance(request, BaseModel):
            request = utils.unmarshal(request, models.CustomMessageCreateRequest)
        request = cast(models.CustomMessageCreateRequest, request)

        req = self._build_request(
            method="POST",
            path="/api/v1/custom_messages/",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request, False, False, "json", models.CustomMessageCreateRequest
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="custom_messages_create",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["422", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.CustomMessageResponse, http_res)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = unmarshal_json_response(
                errors.HTTPValidationErrorData, http_res
            )
            raise errors.HTTPValidationError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)

    async def create_async(
        self,
        *,
        request: Union[
            models.CustomMessageCreateRequest,
            models.CustomMessageCreateRequestTypedDict,
        ],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.CustomMessageResponse:
        r"""Create Custom Message

        Create a new custom message

        :param request: The request object to send.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        if not isinstance(request, BaseModel):
            request = utils.unmarshal(request, models.CustomMessageCreateRequest)
        request = cast(models.CustomMessageCreateRequest, request)

        req = self._build_request_async(
            method="POST",
            path="/api/v1/custom_messages/",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request, False, False, "json", models.CustomMessageCreateRequest
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="custom_messages_create",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["422", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.CustomMessageResponse, http_res)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = unmarshal_json_response(
                errors.HTTPValidationErrorData, http_res
            )
            raise errors.HTTPValidationError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)

    def update(
        self,
        *,
        request: Union[
            models.CustomMessageUpdateRequest,
            models.CustomMessageUpdateRequestTypedDict,
        ],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.CustomMessageResponse:
        r"""Update Custom Message

        Update a custom message

        :param request: The request object to send.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        if not isinstance(request, BaseModel):
            request = utils.unmarshal(request, models.CustomMessageUpdateRequest)
        request = cast(models.CustomMessageUpdateRequest, request)

        req = self._build_request(
            method="PUT",
            path="/api/v1/custom_messages/",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request, False, False, "json", models.CustomMessageUpdateRequest
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="custom_messages_update",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["422", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.CustomMessageResponse, http_res)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = unmarshal_json_response(
                errors.HTTPValidationErrorData, http_res
            )
            raise errors.HTTPValidationError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)

    async def update_async(
        self,
        *,
        request: Union[
            models.CustomMessageUpdateRequest,
            models.CustomMessageUpdateRequestTypedDict,
        ],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.CustomMessageResponse:
        r"""Update Custom Message

        Update a custom message

        :param request: The request object to send.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        if not isinstance(request, BaseModel):
            request = utils.unmarshal(request, models.CustomMessageUpdateRequest)
        request = cast(models.CustomMessageUpdateRequest, request)

        req = self._build_request_async(
            method="PUT",
            path="/api/v1/custom_messages/",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request, False, False, "json", models.CustomMessageUpdateRequest
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="custom_messages_update",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["422", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.CustomMessageResponse, http_res)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = unmarshal_json_response(
                errors.HTTPValidationErrorData, http_res
            )
            raise errors.HTTPValidationError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)

    def get_by_id(
        self,
        *,
        custom_message_id: int,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.CustomMessageResponse:
        r"""Get Custom Message By Id

        Get the custom message by its ID

        :param custom_message_id:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.CustomMessageGetByIDRequest(
            custom_message_id=custom_message_id,
        )

        req = self._build_request(
            method="GET",
            path="/api/v1/custom_messages/{custom_message_id}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="custom_message_get_by_id",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["422", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.CustomMessageResponse, http_res)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = unmarshal_json_response(
                errors.HTTPValidationErrorData, http_res
            )
            raise errors.HTTPValidationError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)

    async def get_by_id_async(
        self,
        *,
        custom_message_id: int,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.CustomMessageResponse:
        r"""Get Custom Message By Id

        Get the custom message by its ID

        :param custom_message_id:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.CustomMessageGetByIDRequest(
            custom_message_id=custom_message_id,
        )

        req = self._build_request_async(
            method="GET",
            path="/api/v1/custom_messages/{custom_message_id}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="custom_message_get_by_id",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["422", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.CustomMessageResponse, http_res)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = unmarshal_json_response(
                errors.HTTPValidationErrorData, http_res
            )
            raise errors.HTTPValidationError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)

    def delete(
        self,
        *,
        custom_message_id: int,
        reason: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> Any:
        r"""Delete Custom Message

        Delete custom message by ID

        :param custom_message_id:
        :param reason:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.CustomMessagesDeleteRequest(
            custom_message_id=custom_message_id,
            reason=reason,
        )

        req = self._build_request(
            method="DELETE",
            path="/api/v1/custom_messages/{custom_message_id}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="custom_messages_delete",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["422", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(Any, http_res)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = unmarshal_json_response(
                errors.HTTPValidationErrorData, http_res
            )
            raise errors.HTTPValidationError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)

    async def delete_async(
        self,
        *,
        custom_message_id: int,
        reason: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> Any:
        r"""Delete Custom Message

        Delete custom message by ID

        :param custom_message_id:
        :param reason:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.CustomMessagesDeleteRequest(
            custom_message_id=custom_message_id,
            reason=reason,
        )

        req = self._build_request_async(
            method="DELETE",
            path="/api/v1/custom_messages/{custom_message_id}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="custom_messages_delete",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["422", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(Any, http_res)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = unmarshal_json_response(
                errors.HTTPValidationErrorData, http_res
            )
            raise errors.HTTPValidationError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .basesdk import BaseSDK
from syllable_sdk import errors, models, utils
from syllable_sdk._hooks import HookContext
from syllable_sdk.types import OptionalNullable, UNSET
from syllable_sdk.utils import get_security_from_env
from syllable_sdk.utils.unmarshal_json_response import unmarshal_json_response
from typing import Any, List, Mapping, Optional
from typing_extensions import deprecated


class Dashboards(BaseSDK):
    r"""Operations related to dashboards. Currently the API/SDK           only supports fetching basic information about dashboards."""

    def post_list_dashboard(
        self,
        *,
        page: OptionalNullable[int] = UNSET,
        limit: Optional[int] = 25,
        search_fields: Optional[List[models.DashboardProperties]] = None,
        search_field_values: Optional[List[str]] = None,
        order_by: OptionalNullable[models.DashboardProperties] = UNSET,
        order_by_direction: OptionalNullable[models.OrderByDirection] = UNSET,
        fields: OptionalNullable[List[models.DashboardProperties]] = UNSET,
        start_datetime: OptionalNullable[str] = UNSET,
        end_datetime: OptionalNullable[str] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.ListResponseDashboardResponse:
        r"""Post List Dashboards

        METHOD: POST
        URL: /dashboard/list
        ARGUMENTS: None
        RETURNS: List of dashboards

        :param page: The page number from which to start (0-based)
        :param limit: The maximum number of items to return
        :param search_fields: String names of fields to search. Correspond by index to search field values
        :param search_field_values: Values of fields to search. Correspond by index to search fields. Unless field name contains \"list\", an individual search field value cannot be a list
        :param order_by: The field whose value should be used to order the results
        :param order_by_direction: The direction in which to order the results
        :param fields: The fields to include in the response
        :param start_datetime: The start datetime for filtering results
        :param end_datetime: The end datetime for filtering results
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.PostListDashboardRequest(
            page=page,
            limit=limit,
            search_fields=search_fields,
            search_field_values=search_field_values,
            order_by=order_by,
            order_by_direction=order_by_direction,
            fields=fields,
            start_datetime=start_datetime,
            end_datetime=end_datetime,
        )

        req = self._build_request(
            method="POST",
            path="/api/v1/dashboards/list",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="post_list_dashboard",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["422", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(
                models.ListResponseDashboardResponse, http_res
            )
        if utils.match_response(http_res, "422", "application/json"):
            response_data = unmarshal_json_response(
                errors.HTTPValidationErrorData, http_res
            )
            raise errors.HTTPValidationError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)

    async def post_list_dashboard_async(
        self,
        *,
        page: OptionalNullable[int] = UNSET,
        limit: Optional[int] = 25,
        search_fields: Optional[List[models.DashboardProperties]] = None,
        search_field_values: Optional[List[str]] = None,
        order_by: OptionalNullable[models.DashboardProperties] = UNSET,
        order_by_direction: OptionalNullable[models.OrderByDirection] = UNSET,
        fields: OptionalNullable[List[models.DashboardProperties]] = UNSET,
        start_datetime: OptionalNullable[str] = UNSET,
        end_datetime: OptionalNullable[str] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.ListResponseDashboardResponse:
        r"""Post List Dashboards

        METHOD: POST
        URL: /dashboard/list
        ARGUMENTS: None
        RETURNS: List of dashboards

        :param page: The page number from which to start (0-based)
        :param limit: The maximum number of items to return
        :param search_fields: String names of fields to search. Correspond by index to search field values
        :param search_field_values: Values of fields to search. Correspond by index to search fields. Unless field name contains \"list\", an individual search field value cannot be a list
        :param order_by: The field whose value should be used to order the results
        :param order_by_direction: The direction in which to order the results
        :param fields: The fields to include in the response
        :param start_datetime: The start datetime for filtering results
        :param end_datetime: The end datetime for filtering results
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.PostListDashboardRequest(
            page=page,
            limit=limit,
            search_fields=search_fields,
            search_field_values=search_field_values,
            order_by=order_by,
            order_by_direction=order_by_direction,
            fields=fields,
            start_datetime=start_datetime,
            end_datetime=end_datetime,
        )

        req = self._build_request_async(
            method="POST",
            path="/api/v1/dashboards/list",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="post_list_dashboard",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["422", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(
                models.ListResponseDashboardResponse, http_res
            )
        if utils.match_response(http_res, "422", "application/json"):
            response_data = unmarshal_json_response(
                errors.HTTPValidationErrorData, http_res
            )
            raise errors.HTTPValidationError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)

    def post_get_dashboard(
        self,
        *,
        dashboard_name: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.DashboardTokenResponse:
        r"""Post Fetch Info

        METHOD: POST
        URL: /dashboard/fetch_info
        ARGUMENTS: None
        RETURNS: Dashboard info for embedding

        :param dashboard_name:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.PostGetDashboardRequest(
            dashboard_name=dashboard_name,
        )

        req = self._build_request(
            method="POST",
            path="/api/v1/dashboards/fetch_info",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="post_get_dashboard",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["422", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.DashboardTokenResponse, http_res)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = unmarshal_json_response(
                errors.HTTPValidationErrorData, http_res
            )
            raise errors.HTTPValidationError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)

    async def post_get_dashboard_async(
        self,
        *,
        dashboard_name: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.DashboardTokenResponse:
        r"""Post Fetch Info

        METHOD: POST
        URL: /dashboard/fetch_info
        ARGUMENTS: None
        RETURNS: Dashboard info for embedding

        :param dashboard_name:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.PostGetDashboardRequest(
            dashboard_name=dashboard_name,
        )

        req = self._build_request_async(
            method="POST",
            path="/api/v1/dashboards/fetch_info",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="post_get_dashboard",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["422", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.DashboardTokenResponse, http_res)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = unmarshal_json_response(
                errors.HTTPValidationErrorData, http_res
            )
            raise errors.HTTPValidationError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)

    @deprecated(
        "warning: ** DEPRECATED ** - This will be removed in a future release, please migrate away from it as soon as possible."
    )
    def post_session_events_dashboard(
        self,
        *,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.Dashboard:
        r"""Post Session Events

        METHOD: POST
        URL: /dashboard/session_events
        ARGUMENTS: None
        RETURNS: Dashboard info for embedding
        DEPRECATED: This endpoint is deprecated. Please use /dashboard/list instead

        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)
        req = self._build_request(
            method="POST",
            path="/api/v1/dashboards/session_events",
            base_url=base_url,
            url_variables=url_variables,
            request=None,
            request_body_required=False,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="post_session_events_dashboard",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["4XX", "5XX"],
            retry_config=retry_config,
        )

        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.Dashboard, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)

    @deprecated(
        "warning: ** DEPRECATED ** - This will be removed in a future release, please migrate away from it as soon as possible."
    )
    async def post_session_events_dashboard_async(
        self,
        *,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.Dashboard:
        r"""Post Session Events

        METHOD: POST
        URL: /dashboard/session_events
        ARGUMENTS: None
        RETURNS: Dashboard info for embedding
        DEPRECATED: This endpoint is deprecated. Please use /dashboard/list instead

        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)
        req = self._build_request_async(
            method="POST",
            path="/api/v1/dashboards/session_events",
            base_url=base_url,
            url_variables=url_variables,
            request=None,
            request_body_required=False,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="post_session_events_dashboard",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["4XX", "5XX"],
            retry_config=retry_config,
        )

        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.Dashboard, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)

    @deprecated(
        "warning: ** DEPRECATED ** - This will be removed in a future release, please migrate away from it as soon as possible."
    )
    def post_session_summary_dashboard(
        self,
        *,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.Dashboard:
        r"""Post Session Summary

        METHOD: POST
        URL: /dashboard/session_summary
        ARGUMENTS: None
        RETURNS: Dashboard info for embedding
        DEPRECATED: This endpoint is deprecated. Please use /dashboard/list instead

        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)
        req = self._build_request(
            method="POST",
            path="/api/v1/dashboards/session_summary",
            base_url=base_url,
            url_variables=url_variables,
            request=None,
            request_body_required=False,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="post_session_summary_dashboard",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["4XX", "5XX"],
            retry_config=retry_config,
        )

        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.Dashboard, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)

    @deprecated(
        "warning: ** DEPRECATED ** - This will be removed in a future release, please migrate away from it as soon as possible."
    )
    async def post_session_summary_dashboard_async(
        self,
        *,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.Dashboard:
        r"""Post Session Summary

        METHOD: POST
        URL: /dashboard/session_summary
        ARGUMENTS: None
        RETURNS: Dashboard info for embedding
        DEPRECATED: This endpoint is deprecated. Please use /dashboard/list instead

        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)
        req = self._build_request_async(
            method="POST",
            path="/api/v1/dashboards/session_summary",
            base_url=base_url,
            url_variables=url_variables,
            request=None,
            request_body_required=False,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="post_session_summary_dashboard",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["4XX", "5XX"],
            retry_config=retry_config,
        )

        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.Dashboard, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)

    @deprecated(
        "warning: ** DEPRECATED ** - This will be removed in a future release, please migrate away from it as soon as possible."
    )
    def post_session_transfers_dashboard(
        self,
        *,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.Dashboard:
        r"""Post Session Transfers

        METHOD: POST
        URL: /dashboard/session_transfers
        ARGUMENTS: None
        RETURNS: Dashboard info for embedding
        DEPRECATED: This endpoint is deprecated. Please use /dashboard/list instead

        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)
        req = self._build_request(
            method="POST",
            path="/api/v1/dashboards/session_transfers",
            base_url=base_url,
            url_variables=url_variables,
            request=None,
            request_body_required=False,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="post_session_transfers_dashboard",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["4XX", "5XX"],
            retry_config=retry_config,
        )

        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.Dashboard, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)

    @deprecated(
        "warning: ** DEPRECATED ** - This will be removed in a future release, please migrate away from it as soon as possible."
    )
    async def post_session_transfers_dashboard_async(
        self,
        *,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.Dashboard:
        r"""Post Session Transfers

        METHOD: POST
        URL: /dashboard/session_transfers
        ARGUMENTS: None
        RETURNS: Dashboard info for embedding
        DEPRECATED: This endpoint is deprecated. Please use /dashboard/list instead

        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)
        req = self._build_request_async(
            method="POST",
            path="/api/v1/dashboards/session_transfers",
            base_url=base_url,
            url_variables=url_variables,
            request=None,
            request_body_required=False,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="post_session_transfers_dashboard",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["4XX", "5XX"],
            retry_config=retry_config,
        )

        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.Dashboard, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)

    @deprecated(
        "warning: ** DEPRECATED ** - This will be removed in a future release, please migrate away from it as soon as possible."
    )
    def post_sessions_dashboard(
        self,
        *,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.Dashboard:
        r"""Post Sessions

        METHOD: POST
        URL: /dashboard/sessions
        ARGUMENTS: None
        RETURNS: Dashboard info for embedding
        DEPRECATED: This endpoint is deprecated. Please use /dashboard/list instead

        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)
        req = self._build_request(
            method="POST",
            path="/api/v1/dashboards/sessions",
            base_url=base_url,
            url_variables=url_variables,
            request=None,
            request_body_required=False,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="post_sessions_dashboard",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["4XX", "5XX"],
            retry_config=retry_config,
        )

        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.Dashboard, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)

    @deprecated(
        "warning: ** DEPRECATED ** - This will be removed in a future release, please migrate away from it as soon as possible."
    )
    async def post_sessions_dashboard_async(
        self,
        *,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.Dashboard:
        r"""Post Sessions

        METHOD: POST
        URL: /dashboard/sessions
        ARGUMENTS: None
        RETURNS: Dashboard info for embedding
        DEPRECATED: This endpoint is deprecated. Please use /dashboard/list instead

        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)
        req = self._build_request_async(
            method="POST",
            path="/api/v1/dashboards/sessions",
            base_url=base_url,
            url_variables=url_variables,
            request=None,
            request_body_required=False,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="post_sessions_dashboard",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["4XX", "5XX"],
            retry_config=retry_config,
        )

        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.Dashboard, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class PromptLlmProvider(str, Enum):
    r"""LLM API provider."""

    AZURE_OPENAI = "azure_openai"
    GOOGLE = "google"
    OPENAI = "openai"



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import httpx
from syllable_sdk.errors import SyllableSDKError
from syllable_sdk.models import validationerror as models_validationerror
from syllable_sdk.types import BaseModel
from typing import List, Optional


class HTTPValidationErrorData(BaseModel):
    detail: Optional[List[models_validationerror.ValidationError]] = None


class HTTPValidationError(SyllableSDKError):
    data: HTTPValidationErrorData

    def __init__(
        self,
        data: HTTPValidationErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        message = body or raw_response.text
        super().__init__(message, raw_response, body)
        self.data = data



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .toolfunction import ToolFunction, ToolFunctionTypedDict
import pydantic
from pydantic.functional_validators import AfterValidator
from syllable_sdk.types import BaseModel
from syllable_sdk.utils import validate_const
from typing import Literal, Optional
from typing_extensions import Annotated, TypedDict


class InternalToolTypedDict(TypedDict):
    r"""A tool definition to be used by the OpenAI API."""

    function: ToolFunctionTypedDict
    r"""A function available to an agent.

    See:
    - https://learn.microsoft.com/en-us/azure/ai-services/openai/how-to/function-calling
    """
    type: Literal["function"]
    r"""Always `function`."""


class InternalTool(BaseModel):
    r"""A tool definition to be used by the OpenAI API."""

    function: ToolFunction
    r"""A function available to an agent.

    See:
    - https://learn.microsoft.com/en-us/azure/ai-services/openai/how-to/function-calling
    """

    TYPE: Annotated[
        Annotated[
            Optional[Literal["function"]], AfterValidator(validate_const("function"))
        ],
        pydantic.Field(alias="type"),
    ] = "function"
    r"""Always `function`."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from pydantic import model_serializer
from syllable_sdk.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from typing_extensions import NotRequired, TypedDict


class ConversationTypedDict(TypedDict):
    r"""A conversation is a record of messages between a user and an agent, and is composed of one or
    more sessions.
    """

    timestamp: datetime
    r"""Timestamp of the conversation"""
    conversation_id: str
    r"""ID of the conversation"""
    agent_id: NotRequired[Nullable[str]]
    r"""ID of the agent with which the conversation occurred"""
    agent_name: NotRequired[Nullable[str]]
    r"""Name of the agent with which the conversation occurred"""
    agent_type: NotRequired[Nullable[str]]
    r"""Value of the \"type\" field of the agent with which the conversation occurred"""
    prompt_id: NotRequired[Nullable[str]]
    r"""ID of the prompt used in the conversation"""
    prompt_name: NotRequired[Nullable[str]]
    r"""Name of the prompt used in the conversation"""
    prompt_version: NotRequired[Nullable[str]]
    r"""Version of the prompt used in the conversation"""
    llm_provider: NotRequired[Nullable[str]]
    r"""Provider for the LLM used in the conversation (see PromptResponse.llm_config.provider)"""
    llm_model: NotRequired[Nullable[str]]
    r"""Model for the LLM used in the conversation (see PromptResponse.llm_config.model)"""
    llm_version: NotRequired[Nullable[str]]
    r"""Version for the LLM used in the conversation (see PromptResponse.llm_config.version)"""
    llm_temperature: NotRequired[Nullable[float]]
    r"""Temperature for the LLM used in the conversation (see PromptResponse.llm_config.temperature)"""
    llm_seed: NotRequired[Nullable[int]]
    r"""Seed for the LLM used in the conversation (see PromptResponse.llm_config.seed)."""
    is_legacy: NotRequired[Nullable[bool]]
    r"""Whether the conversation occurred on the legacy Syllable system"""


class Conversation(BaseModel):
    r"""A conversation is a record of messages between a user and an agent, and is composed of one or
    more sessions.
    """

    timestamp: datetime
    r"""Timestamp of the conversation"""

    conversation_id: str
    r"""ID of the conversation"""

    agent_id: OptionalNullable[str] = UNSET
    r"""ID of the agent with which the conversation occurred"""

    agent_name: OptionalNullable[str] = UNSET
    r"""Name of the agent with which the conversation occurred"""

    agent_type: OptionalNullable[str] = UNSET
    r"""Value of the \"type\" field of the agent with which the conversation occurred"""

    prompt_id: OptionalNullable[str] = UNSET
    r"""ID of the prompt used in the conversation"""

    prompt_name: OptionalNullable[str] = UNSET
    r"""Name of the prompt used in the conversation"""

    prompt_version: OptionalNullable[str] = UNSET
    r"""Version of the prompt used in the conversation"""

    llm_provider: OptionalNullable[str] = UNSET
    r"""Provider for the LLM used in the conversation (see PromptResponse.llm_config.provider)"""

    llm_model: OptionalNullable[str] = UNSET
    r"""Model for the LLM used in the conversation (see PromptResponse.llm_config.model)"""

    llm_version: OptionalNullable[str] = UNSET
    r"""Version for the LLM used in the conversation (see PromptResponse.llm_config.version)"""

    llm_temperature: OptionalNullable[float] = UNSET
    r"""Temperature for the LLM used in the conversation (see PromptResponse.llm_config.temperature)"""

    llm_seed: OptionalNullable[int] = UNSET
    r"""Seed for the LLM used in the conversation (see PromptResponse.llm_config.seed)."""

    is_legacy: OptionalNullable[bool] = UNSET
    r"""Whether the conversation occurred on the legacy Syllable system"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "agent_id",
            "agent_name",
            "agent_type",
            "prompt_id",
            "prompt_name",
            "prompt_version",
            "llm_provider",
            "llm_model",
            "llm_version",
            "llm_temperature",
            "llm_seed",
            "is_legacy",
        ]
        nullable_fields = [
            "agent_id",
            "agent_name",
            "agent_type",
            "prompt_id",
            "prompt_name",
            "prompt_version",
            "llm_provider",
            "llm_model",
            "llm_version",
            "llm_temperature",
            "llm_seed",
            "is_legacy",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from syllable_sdk.types import BaseModel
from syllable_sdk.utils import FieldMetadata, PathParamMetadata, QueryParamMetadata
from typing_extensions import Annotated, TypedDict


class ServiceDeleteRequestTypedDict(TypedDict):
    service_id: int
    reason: str


class ServiceDeleteRequest(BaseModel):
    service_id: Annotated[
        int, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    reason: Annotated[
        str, FieldMetadata(query=QueryParamMetadata(style="form", explode=True))
    ]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .languageconfig import LanguageConfig, LanguageConfigTypedDict
from pydantic import model_serializer
from syllable_sdk.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from typing import List
from typing_extensions import NotRequired, TypedDict


class LanguageGroupCreateRequestTypedDict(TypedDict):
    r"""Request model to create a language group."""

    name: str
    r"""The name of the language group."""
    language_configs: List[LanguageConfigTypedDict]
    r"""Voice and DTMF configurations for each language in the group."""
    skip_current_language_in_message: bool
    r"""Whether a custom message using the language group to generate a language DTMF menu should skip the agent's current language in the menu."""
    description: NotRequired[Nullable[str]]
    r"""Description of the language group."""


class LanguageGroupCreateRequest(BaseModel):
    r"""Request model to create a language group."""

    name: str
    r"""The name of the language group."""

    language_configs: List[LanguageConfig]
    r"""Voice and DTMF configurations for each language in the group."""

    skip_current_language_in_message: bool
    r"""Whether a custom message using the language group to generate a language DTMF menu should skip the agent's current language in the menu."""

    description: OptionalNullable[str] = UNSET
    r"""Description of the language group."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["description"]
        nullable_fields = ["description"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .languagecode import LanguageCode
from syllable_sdk.types import BaseModel
from typing_extensions import TypedDict


class AgentLanguageTypedDict(TypedDict):
    r"""Language option for an agent."""

    name: str
    r"""Name of the language"""
    code: LanguageCode
    r"""BCP 47 codes of languages that Syllable supports."""


class AgentLanguage(BaseModel):
    r"""Language option for an agent."""

    name: str
    r"""Name of the language"""

    code: LanguageCode
    r"""BCP 47 codes of languages that Syllable supports."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from pydantic import model_serializer
from syllable_sdk.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from typing import Dict, Optional, Union
from typing_extensions import NotRequired, TypeAliasType, TypedDict


MetadataTypedDict = TypeAliasType("MetadataTypedDict", Union[str, int, float])


Metadata = TypeAliasType("Metadata", Union[str, int, float])


class InsightsUploadFileTypedDict(TypedDict):
    r"""Response model for an insight upload file."""

    id: int
    r"""System-assigned ID for the upload file"""
    folder_id: int
    r"""System-assigned ID for the folder to which the file belongs"""
    filename: str
    r"""Name of the uploaded file"""
    object_key: str
    r"""Object-store key of the uploaded file"""
    call_id: NotRequired[Nullable[str]]
    r"""Unique identifier for the call associated with the uploaded file"""
    agent_number: NotRequired[Nullable[str]]
    r"""Agent number associated with the uploaded file"""
    customer_number: NotRequired[Nullable[str]]
    r"""Customer number associated with the uploaded file"""
    duration: NotRequired[Nullable[float]]
    r"""Length in seconds of the uploaded recording"""
    start_time: NotRequired[Nullable[datetime]]
    r"""Start time of the uploaded file"""
    end_time: NotRequired[Nullable[datetime]]
    r"""End time of the uploaded file"""
    error_message: NotRequired[Nullable[str]]
    r"""Error message associated with the uploaded file"""
    metadata: NotRequired[Nullable[Dict[str, MetadataTypedDict]]]
    r"""Meta-data associated with the uploaded file"""
    created_at: NotRequired[datetime]
    r"""Timestamp at which insight upload file was created"""


class InsightsUploadFile(BaseModel):
    r"""Response model for an insight upload file."""

    id: int
    r"""System-assigned ID for the upload file"""

    folder_id: int
    r"""System-assigned ID for the folder to which the file belongs"""

    filename: str
    r"""Name of the uploaded file"""

    object_key: str
    r"""Object-store key of the uploaded file"""

    call_id: OptionalNullable[str] = UNSET
    r"""Unique identifier for the call associated with the uploaded file"""

    agent_number: OptionalNullable[str] = UNSET
    r"""Agent number associated with the uploaded file"""

    customer_number: OptionalNullable[str] = UNSET
    r"""Customer number associated with the uploaded file"""

    duration: OptionalNullable[float] = UNSET
    r"""Length in seconds of the uploaded recording"""

    start_time: OptionalNullable[datetime] = UNSET
    r"""Start time of the uploaded file"""

    end_time: OptionalNullable[datetime] = UNSET
    r"""End time of the uploaded file"""

    error_message: OptionalNullable[str] = UNSET
    r"""Error message associated with the uploaded file"""

    metadata: OptionalNullable[Dict[str, Metadata]] = UNSET
    r"""Meta-data associated with the uploaded file"""

    created_at: Optional[datetime] = None
    r"""Timestamp at which insight upload file was created"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "call_id",
            "agent_number",
            "customer_number",
            "duration",
            "start_time",
            "end_time",
            "error_message",
            "metadata",
            "created_at",
        ]
        nullable_fields = [
            "call_id",
            "agent_number",
            "customer_number",
            "duration",
            "start_time",
            "end_time",
            "error_message",
            "metadata",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from pydantic import model_serializer
from syllable_sdk.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from typing_extensions import NotRequired, TypedDict


class IncidentResponseTypedDict(TypedDict):
    r"""Response model for service incident operations."""

    description: str
    r"""Description of the service incident"""
    start_datetime: datetime
    r"""Start time of the incident"""
    resolution_datetime: datetime
    r"""Resolution time of the incident"""
    impact_category: str
    r"""Category of the impact"""
    sessions_impacted: int
    r"""Number of sessions impacted"""
    markdown: str
    r"""Detailed markdown description of the incident"""
    id: int
    r"""The ID of the incident to update"""
    last_updated_by: Nullable[str]
    r"""The email of the user who last updated the incident"""
    organization_id: NotRequired[Nullable[int]]
    r"""The ID of the organization"""
    sub_organization_id: NotRequired[Nullable[int]]
    r"""The ID of the sub-organization"""
    sub_organization: NotRequired[Nullable[str]]
    r"""The name of the sub-organization"""
    created_at: NotRequired[Nullable[datetime]]
    r"""Creation time of the incident"""
    updated_at: NotRequired[Nullable[datetime]]
    r"""Last update time of the incident"""


class IncidentResponse(BaseModel):
    r"""Response model for service incident operations."""

    description: str
    r"""Description of the service incident"""

    start_datetime: datetime
    r"""Start time of the incident"""

    resolution_datetime: datetime
    r"""Resolution time of the incident"""

    impact_category: str
    r"""Category of the impact"""

    sessions_impacted: int
    r"""Number of sessions impacted"""

    markdown: str
    r"""Detailed markdown description of the incident"""

    id: int
    r"""The ID of the incident to update"""

    last_updated_by: Nullable[str]
    r"""The email of the user who last updated the incident"""

    organization_id: OptionalNullable[int] = UNSET
    r"""The ID of the organization"""

    sub_organization_id: OptionalNullable[int] = UNSET
    r"""The ID of the sub-organization"""

    sub_organization: OptionalNullable[str] = UNSET
    r"""The name of the sub-organization"""

    created_at: OptionalNullable[datetime] = UNSET
    r"""Creation time of the incident"""

    updated_at: OptionalNullable[datetime] = UNSET
    r"""Last update time of the incident"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "organization_id",
            "sub_organization_id",
            "sub_organization",
            "created_at",
            "updated_at",
        ]
        nullable_fields = [
            "organization_id",
            "sub_organization_id",
            "sub_organization",
            "created_at",
            "updated_at",
            "last_updated_by",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from syllable_sdk.types import BaseModel
from typing import Any
from typing_extensions import TypedDict


class ToolResultDataTypedDict(TypedDict):
    tool_name: str
    r"""Tool name"""
    tool_result: Any
    r"""Tool result data"""


class ToolResultData(BaseModel):
    tool_name: str
    r"""Tool name"""

    tool_result: Any
    r"""Tool result data"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import pydantic
from pydantic import model_serializer
from syllable_sdk.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class TestMessageTypedDict(TypedDict):
    r"""Message sent in a test chat with an agent."""

    __test__ = False  # pyright: ignore[reportGeneralTypeIssues]

    service_name: str
    r"""Name of the service producing the message"""
    source: str
    r"""Name of the source of the message - identifies the user, like an email or username."""
    test_id: str
    r"""Channel-manager-side ID of the session (see Session.channel_manager_sid)"""
    agent_id: str
    r"""ID of the agent with which the chat is taking place"""
    text: NotRequired[Nullable[str]]
    r"""The text of the message"""
    org_name: NotRequired[Nullable[str]]
    r"""Unused: Name of the organization associated with the agent"""
    override_timestamp: NotRequired[Nullable[str]]
    r"""Override for the timestamp of the message"""
    session_start: NotRequired[bool]
    r"""Whether this message is the start of a new session"""


class TestMessage(BaseModel):
    r"""Message sent in a test chat with an agent."""

    __test__ = False

    service_name: str
    r"""Name of the service producing the message"""

    source: str
    r"""Name of the source of the message - identifies the user, like an email or username."""

    test_id: str
    r"""Channel-manager-side ID of the session (see Session.channel_manager_sid)"""

    agent_id: str
    r"""ID of the agent with which the chat is taking place"""

    text: OptionalNullable[str] = UNSET
    r"""The text of the message"""

    org_name: Annotated[
        OptionalNullable[str],
        pydantic.Field(
            deprecated="warning: ** DEPRECATED ** - This will be removed in a future release, please migrate away from it as soon as possible."
        ),
    ] = UNSET
    r"""Unused: Name of the organization associated with the agent"""

    override_timestamp: OptionalNullable[str] = UNSET
    r"""Override for the timestamp of the message"""

    session_start: Optional[bool] = False
    r"""Whether this message is the start of a new session"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["text", "org_name", "override_timestamp", "session_start"]
        nullable_fields = ["text", "org_name", "override_timestamp"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class LanguageCode(str, Enum):
    r"""BCP 47 codes of languages that Syllable supports."""

    YUE_HK = "yue-HK"
    EN_US = "en-US"
    KO_KR = "ko-KR"
    ZH_CN = "zh-CN"
    FA_IR = "fa-IR"
    ES_US = "es-US"
    TH_TH = "th-TH"
    VI_VN = "vi-VN"
    BS_BA = "bs-BA"
    SW_KE = "sw-KE"



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class DashboardProperties(str, Enum):
    r"""Names of dashboard fields supported for filtering/sorting on list endpoint."""

    ID = "id"
    NAME = "name"
    DISPLAY_NAME = "display_name"
    RANK = "rank"
    LABEL = "label"



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class LatencyUnitType(str, Enum):
    MINUTES = "minutes"
    SECONDS = "seconds"
    MILLISECONDS = "milliseconds"
    MICROSECONDS = "microseconds"
    NANOSECONDS = "nanoseconds"



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class ChannelTargetProperties(str, Enum):
    r"""Names of channel target fields supported for filtering/sorting on full channel targets list
    endpoint.
    """

    ID = "id"
    CHANNEL_ID = "channel_id"
    CHANNEL_NAME = "channel_name"
    AGENT_ID = "agent_id"
    TARGET = "target"
    TARGET_MODE = "target_mode"
    FALLBACK_TARGET = "fallback_target"
    IS_TEST = "is_test"
    UPDATED_AT = "updated_at"



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .agentvoicedisplayname import AgentVoiceDisplayName
from .languagecode import LanguageCode
from .ttsprovider import TtsProvider
from pydantic import model_serializer
from syllable_sdk.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from typing_extensions import NotRequired, TypedDict


class VoiceSampleCreateRequestTypedDict(TypedDict):
    r"""Request model to generate a sample audio file for a given voice and language."""

    language_code: LanguageCode
    r"""BCP 47 codes of languages that Syllable supports."""
    voice_provider: TtsProvider
    r"""TTS provider for an agent voice."""
    voice_display_name: AgentVoiceDisplayName
    r"""Display names of voices that Syllable supports."""
    voice_speed: NotRequired[Nullable[float]]
    r"""Speed of the voice in the range of 0.25 to 4.0 (OpenAI and Google) or 0.7 to 1.2 (ElevenLabs). Standard speed is 1.0."""
    voice_pitch: NotRequired[Nullable[float]]
    r"""Pitch of the voice in the range of -20.0 to 20.0. 20 means increase 20 semitones from the original pitch. -20 means decrease 20 semitones from the original pitch. 0 means use the original pitch. Only supported for Google configs."""


class VoiceSampleCreateRequest(BaseModel):
    r"""Request model to generate a sample audio file for a given voice and language."""

    language_code: LanguageCode
    r"""BCP 47 codes of languages that Syllable supports."""

    voice_provider: TtsProvider
    r"""TTS provider for an agent voice."""

    voice_display_name: AgentVoiceDisplayName
    r"""Display names of voices that Syllable supports."""

    voice_speed: OptionalNullable[float] = UNSET
    r"""Speed of the voice in the range of 0.25 to 4.0 (OpenAI and Google) or 0.7 to 1.2 (ElevenLabs). Standard speed is 1.0."""

    voice_pitch: OptionalNullable[float] = UNSET
    r"""Pitch of the voice in the range of -20.0 to 20.0. 20 means increase 20 semitones from the original pitch. -20 means decrease 20 semitones from the original pitch. 0 means use the original pitch. Only supported for Google configs."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["voice_speed", "voice_pitch"]
        nullable_fields = ["voice_speed", "voice_pitch"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .twilionumberupdaterequest import (
    TwilioNumberUpdateRequest,
    TwilioNumberUpdateRequestTypedDict,
)
from syllable_sdk.types import BaseModel
from syllable_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class ChannelsTwilioNumbersUpdateRequestTypedDict(TypedDict):
    channel_id: int
    twilio_number_update_request: TwilioNumberUpdateRequestTypedDict


class ChannelsTwilioNumbersUpdateRequest(BaseModel):
    channel_id: Annotated[
        int, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    twilio_number_update_request: Annotated[
        TwilioNumberUpdateRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from syllable_sdk.types import BaseModel
from typing_extensions import TypedDict


class ToolAgentInfoTypedDict(TypedDict):
    r"""Information about an agent linked to a tool via a prompt."""

    id: int
    r"""The internal ID of the agent"""
    name: str
    r"""The name of the agent"""


class ToolAgentInfo(BaseModel):
    r"""Information about an agent linked to a tool via a prompt."""

    id: int
    r"""The internal ID of the agent"""

    name: str
    r"""The name of the agent"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .insightworkflowcondition import (
    InsightWorkflowCondition,
    InsightWorkflowConditionTypedDict,
)
from datetime import datetime
from pydantic import model_serializer
from syllable_sdk.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from typing import List
from typing_extensions import NotRequired, TypedDict


class InsightWorkflowInputTypedDict(TypedDict):
    r"""Request model to create/update an insight workflow."""

    name: str
    r"""Human-readable name of insight workflow"""
    source: str
    r"""Source of the workflow"""
    description: str
    r"""Text description of workflow"""
    insight_tool_ids: List[int]
    r"""Ordered list of IDs of tool configurations to be executed in the workflow"""
    conditions: InsightWorkflowConditionTypedDict
    r"""Model for the conditions that trigger an insight workflow."""
    start_datetime: NotRequired[Nullable[datetime]]
    r"""Target session timestamp the workflow (backfill) should start. An empty value indicates start on activation - live sessions only"""
    end_datetime: NotRequired[Nullable[datetime]]
    r"""Target session timestamp the workflow (backfill) should end. An empty value indicates no end, i.e., include live sessions until deactivation"""


class InsightWorkflowInput(BaseModel):
    r"""Request model to create/update an insight workflow."""

    name: str
    r"""Human-readable name of insight workflow"""

    source: str
    r"""Source of the workflow"""

    description: str
    r"""Text description of workflow"""

    insight_tool_ids: List[int]
    r"""Ordered list of IDs of tool configurations to be executed in the workflow"""

    conditions: InsightWorkflowCondition
    r"""Model for the conditions that trigger an insight workflow."""

    start_datetime: OptionalNullable[datetime] = UNSET
    r"""Target session timestamp the workflow (backfill) should start. An empty value indicates start on activation - live sessions only"""

    end_datetime: OptionalNullable[datetime] = UNSET
    r"""Target session timestamp the workflow (backfill) should end. An empty value indicates no end, i.e., include live sessions until deactivation"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["start_datetime", "end_datetime"]
        nullable_fields = ["start_datetime", "end_datetime"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .custommessagerule import CustomMessageRule, CustomMessageRuleTypedDict
from datetime import datetime
from pydantic import model_serializer
from syllable_sdk.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class CustomMessageResponseTypedDict(TypedDict):
    r"""Response model for custom message operations.
    A custom message is a pre-configured message delivered by an agent as a greeting at the
    beginning of a conversation. Multiple agents can use the same custom mesasage. A custom message
    has one or more rules defined, which allow for different messages to be dynamically selected and
    delivered at runtime based on the current time and either date or day of the week. For more
    information, see [Console docs](https://docs.syllable.ai/Resources/Messages).
    """

    name: str
    r"""The name of the custom message"""
    text: str
    r"""The default message that the agent will deliver if no rules are set or no rules match the current timestamp."""
    id: int
    r"""The ID of the custom message"""
    updated_at: datetime
    r"""Timestamp of the most recent update to the custom message"""
    last_updated_by: str
    r"""The email address of the user who most recently updated the custom message"""
    label: NotRequired[Nullable[str]]
    r"""The label of the custom message"""
    rules: NotRequired[List[CustomMessageRuleTypedDict]]
    r"""Rules for time-specific message variants"""
    agent_count: NotRequired[Nullable[int]]
    r"""The number of agents using the custom message"""
    type: NotRequired[str]
    r"""Type of the custom message (must be \"greeting\" for now)"""


class CustomMessageResponse(BaseModel):
    r"""Response model for custom message operations.
    A custom message is a pre-configured message delivered by an agent as a greeting at the
    beginning of a conversation. Multiple agents can use the same custom mesasage. A custom message
    has one or more rules defined, which allow for different messages to be dynamically selected and
    delivered at runtime based on the current time and either date or day of the week. For more
    information, see [Console docs](https://docs.syllable.ai/Resources/Messages).
    """

    name: str
    r"""The name of the custom message"""

    text: str
    r"""The default message that the agent will deliver if no rules are set or no rules match the current timestamp."""

    id: int
    r"""The ID of the custom message"""

    updated_at: datetime
    r"""Timestamp of the most recent update to the custom message"""

    last_updated_by: str
    r"""The email address of the user who most recently updated the custom message"""

    label: OptionalNullable[str] = UNSET
    r"""The label of the custom message"""

    rules: Optional[List[CustomMessageRule]] = None
    r"""Rules for time-specific message variants"""

    agent_count: OptionalNullable[int] = UNSET
    r"""The number of agents using the custom message"""

    type: Optional[str] = "greeting"
    r"""Type of the custom message (must be \"greeting\" for now)"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["label", "rules", "agent_count", "type"]
        nullable_fields = ["label", "agent_count"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .internaltool import InternalTool, InternalToolTypedDict
from .statictoolparameter import StaticToolParameter, StaticToolParameterTypedDict
from .toolhttpendpoint import ToolHTTPEndpoint, ToolHTTPEndpointTypedDict
from .tooloptions import ToolOptions, ToolOptionsTypedDict
from .toolparameterdefault import ToolParameterDefault, ToolParameterDefaultTypedDict
from enum import Enum
from pydantic import model_serializer
from syllable_sdk.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from typing import Any, Dict, List, Union
from typing_extensions import NotRequired, TypeAliasType, TypedDict


class Type(str, Enum):
    ACTION = "action"
    ENDPOINT = "endpoint"
    CONTEXT = "context"
    LOG = "log"


DefaultsTypedDict = TypeAliasType(
    "DefaultsTypedDict", Union[Any, Dict[str, ToolParameterDefaultTypedDict]]
)
r"""The default values for the parameters of the function/tool call."""


Defaults = TypeAliasType("Defaults", Union[Any, Dict[str, ToolParameterDefault]])
r"""The default values for the parameters of the function/tool call."""


class ToolDefinitionTypedDict(TypedDict):
    r"""A tool that can be called from an LLM during the conversation. See https://docs.syllable.ai/Resources/Tools."""

    tool: InternalToolTypedDict
    r"""A tool definition to be used by the OpenAI API."""
    type: NotRequired[Nullable[Type]]
    r"""The action to take when the LLM calls the tool."""
    endpoint: NotRequired[Nullable[ToolHTTPEndpointTypedDict]]
    r"""The configuration for an HTTP API call."""
    defaults: NotRequired[Nullable[DefaultsTypedDict]]
    r"""The default values for the parameters of the function/tool call."""
    static_parameters: NotRequired[Nullable[List[StaticToolParameterTypedDict]]]
    r"""Parameters for the tool whose values should be set at config time (i.e., not provided by the LLM)."""
    result: NotRequired[Nullable[Any]]
    r"""The optional result of the tool call."""
    options: NotRequired[Nullable[ToolOptionsTypedDict]]
    r"""The options for the tool. Ie allows to propagate the tool result to the caller via propagate_tool_result flag."""


class ToolDefinition(BaseModel):
    r"""A tool that can be called from an LLM during the conversation. See https://docs.syllable.ai/Resources/Tools."""

    tool: InternalTool
    r"""A tool definition to be used by the OpenAI API."""

    type: OptionalNullable[Type] = UNSET
    r"""The action to take when the LLM calls the tool."""

    endpoint: OptionalNullable[ToolHTTPEndpoint] = UNSET
    r"""The configuration for an HTTP API call."""

    defaults: OptionalNullable[Defaults] = UNSET
    r"""The default values for the parameters of the function/tool call."""

    static_parameters: OptionalNullable[List[StaticToolParameter]] = UNSET
    r"""Parameters for the tool whose values should be set at config time (i.e., not provided by the LLM)."""

    result: OptionalNullable[Any] = UNSET
    r"""The optional result of the tool call."""

    options: OptionalNullable[ToolOptions] = UNSET
    r"""The options for the tool. Ie allows to propagate the tool result to the caller via propagate_tool_result flag."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "type",
            "endpoint",
            "defaults",
            "static_parameters",
            "result",
            "options",
        ]
        nullable_fields = [
            "type",
            "endpoint",
            "defaults",
            "static_parameters",
            "result",
            "options",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class UserActivityStatus(str, Enum):
    NOT_INVITED = "not_invited"
    INVITED = "invited"
    ACTIVE = "active"



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from pydantic import model_serializer
from syllable_sdk.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class DataSourceUpdateRequestTypedDict(TypedDict):
    r"""Request model to update an existing data source."""

    name: str
    r"""The data source name. Must be unique within suborg. Cannot contain whitespace."""
    chunk: bool
    r"""Whether the content should be split into smaller chunks. (This feature is coming in the future - currently this value will always be treated as False.)"""
    id: int
    r"""The data source ID."""
    text: str
    r"""Information that the data source will provide to the agent accessing it. It is recommended to include a sentence at the beginning providing context to the LLM for the information in the data source."""
    description: NotRequired[Nullable[str]]
    r"""The description of the data source."""
    labels: NotRequired[List[str]]
    r"""Searchable labels for the data source. Can be included in agent.prompt_tool_defaults for a given tool to give the agent access to data sources with those labels when calling that tool."""
    chunk_delimiter: NotRequired[Nullable[str]]
    r"""String that should be treated as delimiter between intended chunks. (This feature is coming in the future - currently this value will always be treated as None.)"""
    edit_comments: NotRequired[Nullable[str]]
    r"""The comments for the most recent edit to the data source"""


class DataSourceUpdateRequest(BaseModel):
    r"""Request model to update an existing data source."""

    name: str
    r"""The data source name. Must be unique within suborg. Cannot contain whitespace."""

    chunk: bool
    r"""Whether the content should be split into smaller chunks. (This feature is coming in the future - currently this value will always be treated as False.)"""

    id: int
    r"""The data source ID."""

    text: str
    r"""Information that the data source will provide to the agent accessing it. It is recommended to include a sentence at the beginning providing context to the LLM for the information in the data source."""

    description: OptionalNullable[str] = UNSET
    r"""The description of the data source."""

    labels: Optional[List[str]] = None
    r"""Searchable labels for the data source. Can be included in agent.prompt_tool_defaults for a given tool to give the agent access to data sources with those labels when calling that tool."""

    chunk_delimiter: OptionalNullable[str] = UNSET
    r"""String that should be treated as delimiter between intended chunks. (This feature is coming in the future - currently this value will always be treated as None.)"""

    edit_comments: OptionalNullable[str] = UNSET
    r"""The comments for the most recent edit to the data source"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["description", "labels", "chunk_delimiter", "edit_comments"]
        nullable_fields = ["description", "chunk_delimiter", "edit_comments"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .communicationbatchupdate import (
    CommunicationBatchUpdate,
    CommunicationBatchUpdateTypedDict,
)
from syllable_sdk.types import BaseModel
from syllable_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class OutboundBatchUpdateRequestTypedDict(TypedDict):
    batch_id: str
    communication_batch_update: CommunicationBatchUpdateTypedDict


class OutboundBatchUpdateRequest(BaseModel):
    batch_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    communication_batch_update: Annotated[
        CommunicationBatchUpdate,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class DayOfWeek(str, Enum):
    r"""Available options for day of the week for use in message rules."""

    MO = "mo"
    TU = "tu"
    WE = "we"
    TH = "th"
    FR = "fr"
    SA = "sa"
    SU = "su"
